@@ -78,7 +78,7 @@ use Sys::Virt::NWFilter;
 use Sys::Virt::DomainSnapshot;
 use Sys::Virt::Stream;
 
-our $VERSION = '1.1.0';
+our $VERSION = '1.1.2';
 require XSLoader;
 XSLoader::load('Sys::Virt', $VERSION);
 
@@ -239,6 +239,29 @@ sub create_domain {
     return Sys::Virt::Domain->_new(connection => $self, xml => $xml, flags => $flags);
 }
 
+=item my $dom = $vmm->create_domain_with_files($xml, $fds, $flags);
+
+Create a new domain based on the XML description passed into the C<$xml>
+parameter. The returned object is an instance of the L<Sys::Virt::Domain>
+class. This method is not available with unprivileged connections to
+the VMM. The C<$fds> parameter is an array of UNIX file descriptors
+which will be passed to the init process of the container. This is
+only supported with container based virtualization. The C<$flags>
+parameter accepts one of the DOMAIN CREATION constants documented
+in L<Sys::Virt::Domain>, and defaults to 0 if omitted.
+
+=cut
+
+sub create_domain_with_files {
+    my $self = shift;
+    my $xml = shift;
+    my $fds = shift;
+    my $flags = shift || 0;
+
+    return Sys::Virt::Domain->_new(connection => $self, xml => $xml,
+				   fds => $fds, flags => $flags);
+}
+
 =item my $dom = $vmm->define_domain($xml);
 
 Defines, but does not start, a new domain based on the XML description
@@ -1525,7 +1548,16 @@ Remove the previously registered close callback.
 Given an array ref whose elements are XML documents describing host CPUs,
 compute the baseline CPU model that is operable across all hosts. The
 XML for the baseline CPU model is returned. The optional C<$flags>
-parameter is currently unused and defaults to 0.
+parameter can take one of
+
+=over 4
+
+=item Sys::Virt::BASELINE_CPU_EXPAND_FEATURES
+
+Expand the CPU definition to list all feature flags, even those
+implied by the model name.
+
+=back
 
 =item my $info = $con->get_node_security_model()
 
